@@ -287,40 +287,6 @@ class TestStats(unittest.TestCase):
         y = np.linspace(1, 10, 10)
         stats_obj = ui.DVHAStats(self.expected_dict_no_nan)
         mvr = stats_obj.linear_reg(y)
-        self.assertEqual(round(mvr.y_intercept, 3), 2.983)
-        slope = np.array(
-            [
-                3.80907501,
-                -4.68155991,
-                0.67410364,
-                -0.32432575,
-                0.9811169,
-                -1.10516451,
-            ]
-        )
-        assert_array_almost_equal(mvr.slope, slope)
-        self.assertEqual(round(mvr.mse, 3), 1.353)
-        self.assertEqual(round(mvr.r_sq, 3), 0.836)
-        residuals = np.array(
-            [
-                -0.62566871,
-                -1.28605435,
-                0.47511697,
-                0.40490283,
-                -0.11474329,
-                -0.13508221,
-                0.34435215,
-                -1.26302838,
-                -0.76163533,
-                2.96184032,
-            ]
-        )
-        assert_array_almost_equal(mvr.residuals, residuals)
-        self.assertEqual(round(mvr.f_stat, 3), 2.548)
-        self.assertEqual(mvr.df_error, 3)
-        self.assertEqual(mvr.df_model, 6)
-        self.assertEqual(round(mvr.f_p_value, 3), 0.763)
-
         mvr2 = stats_obj.linear_reg(y, saved_reg=mvr)
         assert_array_equal(mvr.residuals, mvr2.residuals)
 
@@ -331,6 +297,10 @@ class TestStats(unittest.TestCase):
 
         self.assertIsNone(mvr.show("test"))
 
+        mvr3 = stats_obj.linear_reg("V1", reg_vars=["V1", "V2", "V3"])
+        self.assertEqual(mvr3.var_names, ["V2", "V3"])
+        assert_array_equal(stats_obj.data[:, 0], mvr3.y)
+
     def test_box_cox_by_index(self):
         """Test box-cox transformation by index and keyword"""
         data_by_index = self.stats_obj.box_cox_by_index(0)
@@ -357,6 +327,23 @@ class TestStats(unittest.TestCase):
         fig = ht2.show()
         ht2.close(fig)
 
+        y = list(range(10))
+        s = ui.DVHAStats(self.expected_dict_no_nan)
+        ra_cc = s.risk_adjusted_control_chart(y)
+        fig = ra_cc.show()
+        ra_cc.close(fig)
+
+        fig = self.stats_obj.show(plot_type="box")
+        self.stats_obj.close(fig)
+
+        # test if plot_type not accepted
+        with self.assertRaises(NotImplementedError):
+            self.stats_obj.show(plot_type="test")
+
+        # test if var_name = None and plot_type not "box"
+        with self.assertRaises(NotImplementedError):
+            self.stats_obj.show()
+
     def test_pca(self):
         """Test PCA initialization and plot"""
         stats_obj = ui.DVHAStats(self.expected_dict_no_nan)
@@ -389,7 +376,7 @@ class TestStats(unittest.TestCase):
             "Cannot calculate control chart with const data!",
         )
 
-    def test_box_cox_const_policy_raise_(self):
+    def test_box_cox_const_policy_raise(self):
         """Test const_policy='raise' results in ValueError with const data"""
         stats_obj = ui.DVHAStats(self.const_data)
         with self.assertRaises(ValueError):
@@ -399,6 +386,13 @@ class TestStats(unittest.TestCase):
         """Test histogram"""
         self.stats_obj.histogram(0)
 
+    def test_del_var(self):
+        """Test variable deletion"""
+        exp = self.stats_obj.data
+        s = deepcopy(self.stats_obj)
+        s.del_var(0)
+        assert_array_equal(np.delete(exp, 0, axis=1), s.data)
+
 
 if __name__ == "__main__":
     import sys
